"""
这是Fishconsole Project的后台安装模块，无需调用，因为根本就没有函数，他的存在仅仅只是为了缓解我看Fishsys的压力罢了

----

"""
try:
    import os

    fileprotect = r'''
    
    

    
    
try:  
    import time
    
    try:
        from Fishconsole import *
    
    except ImportError:
        import os
    
        os.system("pip install Fishconsole")
    import os
    import requests
    
    
    
    
    print(logs.日志("Fishconsole Project资源文件保护后台启动","绿色"))
    while True:
    
        try:
            Fishconsole_logo = open("C:\Fishconsole\img\Fishconsole.png", "rb")
            Fishconsole_logo.read()
        except:
            print("文件未找到，程序将会自动下载")
            try:
                res = requests.get("https://s2.loli.net/2022/06/30/GTxdluDELZ9tob3.png").content
                with open("C:\Fishconsole\img\Fishconsole.png", "wb+") as Fishconsole_logo:
                    Fishconsole_logo.write(res)
            except:
                pass

        try:
            houtai_core = open("C:\Fishconsole\programes\Tempfiles\houtai_core.fcc", "r")
            houtai_core.read()
        except:
            pass
            
        try:  
            ipCore = open("C:\Fishconsole\programes\Tempfiles\ipCore.fcc", "r")
            ipCore.read()
        except:
            pass










    
        time.sleep(20) #没必要使用input开假循环，因为有可能你的文件会因为网络的原因没有被下下来，如果没有被下下来就循环，下下来就不管，毕竟现在看起来也没怎么耗后台
    
    
except KeyboardInterrupt:
    from Fishconsole import logs
    print(logs.日志('Fishconsole Fileprotect 已安全退出','蓝色'))

    
    '''

    代理池 =\
r'''


import os
from Fishconsole import logs
pid =os.getpid()
print(logs.日志(f'Fishconsole 随机ip代理池启动{pid}' ,'绿色'))

try:
    def 爬虫进程():
        try:
            import requests
            import re
            from lxml import etree
            from Fishconsole import files, logs, fcv
            import time

            print(logs.日志('爬虫进程启动', 色选='青色'))

            原始代理池 = []
            计数器 = 0

            while True:
                try:
                    if 计数器 == 7:
                        break


                    res = requests.get(f'https://free.kuaidaili.com/free/inha/{str(计数器)}').text

                    res = etree.HTML(res)

                    原始ip = res.xpath('//tbody/tr/td[1]/text()')

                    原始端口 = res.xpath('//tbody/tr/td[2]/text()')
                    初始化代理池 = list(zip(原始ip, 原始端口))
                    for a, b in 初始化代理池:
                        c = a + ':' + b
                        原始代理池.append(c)
                        print(logs.日志(f"1号爬虫爬取完毕，现在的初始代理池为{len(原始代理池)}个",色选='青色'))
                    计数器 = 计数器 + 1
                except:
                    print(logs.日志("爬虫进程报错，十秒后重启"))
                    time.sleep(10)




            while True:
                try:

                    链接 = "https://uu-proxy.com/api/free"

                    res = requests.get(链接).text
                    原始ip = re.findall('"ip":"(.*?)",', res)
                    原始端口 = re.findall('"port":(.*?),', res)
                    初始化代理池 = list(zip(原始ip, 原始端口))

                    for a, b in 初始化代理池:
                        c = a + ':' + b
                        原始代理池.append(c)
                        print(logs.日志(f"2号爬虫爬取完毕，现在的初始代理池为{len(原始代理池)}个",色选='青色'))
                except:
                    print(logs.日志("爬虫进程报错，十秒后重启"))
                    time.sleep(10)
                try:
                    计数器 = 0
                    while True:
                        if 计数器 == 3:
                            break

                        res = requests.get(f'https://ip.jiangxianli.com/?page={计数器}').text
                        res = etree.HTML(res)

                        原始ip = res.xpath('/html/body/div[1]/div[2]/div[1]/div[1]/table/tbody/tr/td[1]/text()')
                        原始端口 = res.xpath('/html/body/div[1]/div[2]/div[1]/div[1]/table/tbody/tr/td[2]/text()')

                        初始化代理池 = list(zip(原始ip, 原始端口))

                        for a, b in 初始化代理池:
                            c = a + ':' + b
                            原始代理池.append(c)
                            print(logs.日志(f"3号爬虫爬取完毕，现在的初始代理池为{len(原始代理池)}个",色选='青色'))

                        计数器 = 计数器 + 1
                except:
                    print(logs.日志("爬虫进程报错，十秒后重启"))
                    time.sleep(10)
                计数器 = 0
                try:
                    while True:

                        res = etree.HTML(requests.get(f'http://www.ip3366.net/?page={计数器}').text)
                        原始ip = res.xpath('//*[@id="list"]/table/tbody/tr/td[1]/text()')
                        原始端口 = res.xpath('//*[@id="list"]/table/tbody/tr/td[2]/text()')
                        初始化代理池 = list(zip(原始ip, 原始端口))

                        for a, b in 初始化代理池:
                            c = a + ':' + b
                            原始代理池.append(c)
                            print(logs.日志(f"4号爬虫爬取完毕，现在的初始代理池为{len(原始代理池)}个",色选='青色'))
                        if 计数器 == 5:
                            break

                        计数器 = 计数器 + 1

                    res = etree.HTML(requests.get('https://ip.ihuan.me/address/5Lit5Zu9.html?page=f3k1d581').text)
                    原始ip = res.xpath('//tbody/tr/td[1]/a/text()')
                    原始端口 = res.xpath('//table/tbody/tr/td[2]/text()')
                    初始化代理池 = list(zip(原始ip, 原始端口))

                    for a, b in 初始化代理池:
                        c = a + ':' + b
                        原始代理池.append(c)
                except:
                    print(logs.日志("爬虫进程报错，十秒后重启"))
                    time.sleep(10)

                计数器 = 0
                原始ip_清洗存储 = []
                原始端口_清洗存储 = []
                try:
                    while True:
                        if 计数器 == 5:
                            break

                        res = etree.HTML(requests.get(f'https://www.89ip.cn/index_{计数器}.html').text)
                        原始ip = res.xpath('//tbody/tr/td[1]/text()')
                        原始端口 = res.xpath('//tbody/tr/td[2]/text()')

                        for a in 原始ip:
                            原始ip_清洗 = re.sub('\t', '', a)
                            原始ip_清洗 = re.sub('\n', '', 原始ip_清洗)
                            原始ip_清洗存储.append(原始ip_清洗)

                        for a in 原始端口:
                            原始端口_清洗 = re.sub('\t', '', a)
                            原始端口_清洗 = re.sub('\n', '', 原始端口_清洗)
                            原始端口_清洗存储.append(原始端口_清洗)

                        初始化代理池 = list(zip(原始ip_清洗存储, 原始端口_清洗存储))

                        for a, b in 初始化代理池:
                            c = a + ':' + b
                            print(logs.日志(f"5号爬虫爬取完毕，现在的初始代理池为{len(原始代理池)}个", 色选='青色'))

                            原始代理池.append(c)

                        计数器 = 计数器 + 1

                    from Fishconsole import Fishsys
                    print(原始代理池)
                except:
                    print(logs.日志("爬虫进程报错，十秒后重启"))
                    time.sleep(10)

                去重代理池 = Fishsys.list去重(原始代理池)
                if not files.文件存在性检测('C:\Fishconsole\programes\Tempfiles\ipCore.fcc'):
                    files.缓存(1, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 数据={'original_agent': 去重代理池})
                else:
                    files.缓存(3, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 数据={'original_agent': 去重代理池})
                print(len(原始代理池))
                print(len(去重代理池))
                print(logs.日志(f'爬虫进程睡眠1000秒钟，本次去重{len(原始代理池)-len(去重代理池)}条项目，剩下{len(去重代理池)}', 色选='青色'))
                time.sleep(1000)
        except KeyboardInterrupt:
            from Fishconsole import logs
            print(logs.日志('Fishconsole ipmadom(爬虫进程) 已安全退出', '蓝色'))




    def 验证进程():
        try:
            from Fishconsole import logs
            from Fishconsole import files
            print(logs.日志('验证进程启动', 色选='蓝色'))
            import requests
            import threading
            from Fishconsole import Fishsys, files
            import time
            可用代理 = []
            线程池 = []

            def 解析器(数据源):

                try:
                    for a in 数据源:
                        # print(logs.日志(f"验证代理{a}","蓝色"))
                        try:
                            proxies = {'http': a, 'https': a}
                            res = requests.get(
                                'https://www.kuaidaili.com/dps/?utm_source=ggtg&utm_campaign=D5b0&utm_medium=D4&gclid=EAIaIQobChMI9Oziy_Tv-AIVescWBR1MrgGkEAEYASAAEgKPhvD_BwE',
                                proxies=proxies, timeout=15).text
                            可用代理.append(a)

                        except:
                            pass

                except SystemExit:
                    exit()

            while True:
                原始代理 = files.缓存(模式=2, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 变量名='original_agent')
                if 原始代理 == False:
                    原始代理 = []
                验证代理 = files.缓存(模式=2, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 变量名='Available')


                if 验证代理 == False:
                    验证代理 = []
                if 验证代理 == 'error':
                    验证代理 = []
                try:
                    数据源 = 原始代理 + 验证代理
                except TypeError:
                    数据源=[]


                try:
                    for a in Fishsys.任务平均分配(29, 数据源):
                        线程池.append(threading.Thread(target=解析器, kwargs={'数据源': a}))
                        线程池[-1].start()
                    for 守护 in 线程池:
                        守护.join()
                except:
                    files.缓存(模式=3, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 数据={'Available': []})





                print(logs.日志(f'验证进程已完成{len(数据源)}条代理的验证,可用代理有{len(Fishsys.list去重(可用代理))}个', 色选='蓝色'))

                files.缓存(3, 文件名='C:\Fishconsole\programes\Tempfiles\ipCore.fcc', 数据={'Available': Fishsys.list去重(可用代理)})

                可用代理 = []

                del 数据源
                print(logs.日志('验证进程睡眠二十秒钟', 色选='蓝色'))

                time.sleep(20)
        except KeyboardInterrupt:
            from Fishconsole import logs
            print(logs.日志('Fishconsole ipmadom(验证进程) 已安全退出', '蓝色'))


    if __name__ == '__main__':
        from Fishconsole import logs ,files ,Fishsys
        import multiprocessing
        import time



        缓存文件名 = 'C:\Fishconsole\programes\Tempfiles\houtai_core.fcc'

        print('loading..25%')
        爬虫进程回调 = multiprocessing.Queue()
        验证进程回调 = multiprocessing.Queue()
        print('loading..50%')
        爬虫进程启动器 = multiprocessing.Process(target=爬虫进程)
        验证进程启动器 = multiprocessing.Process(target=验证进程)
        爬虫进程启动器.setDaemon = True
        验证进程启动器.setDaemon = True
        print('loading..75%')
        爬虫进程启动器.start()
        验证进程启动器.start()
        print('loading..100%')
        爬虫进程启动器.join()
        验证进程启动器.join()
except KeyboardInterrupt:
    from Fishconsole import logs
    from Fishconsole import files

    print(logs.日志('Fishconsole ipmadom 已安全退出', '蓝色'))




 '''

    start = """start python  C:\Fishconsole\programes\Management\Management.py"""

    后台管理器='''
    
try:
    from Fishconsole import Fishsys


    def file_protect():
        import sys
        import  os
        本进程的pid=os.getpid()
        缓存文件名 = 'C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc'
        from Fishconsole import files
        files.缓存(3,文件名=缓存文件名,数据={'FileprotectPid':本进程的pid})
        sys.path.append(r'C:\Fishconsole\programes\FileProtect')
        try:
            import File_Protect.py #这是特性，不用管它报错
        except ModuleNotFoundError:
            pass
        
        
    def ipmadom():
        import sys
        import  os
        本进程的pid=os.getpid()
        缓存文件名 = 'C:\\Fishconsole\\programes\\Tempfiles\\houtai_core.fcc'
        from Fishconsole import files
        files.缓存(3,文件名=缓存文件名,数据={'ipmadomPid':本进程的pid})
        try:
            os.system("python C:\Fishconsole\programes\ipmadom\ipmadom.py")
        except KeyboardInterrupt:
            from Fishconsole import logs
            print(logs.日志("ipmadom安全退出","蓝色"))

    if __name__ == '__main__':
        import multiprocessing
        import os
        from Fishconsole import files, logs,Fishsys
        import time

        # 这里有一个致命的问题，就是这个主进程没有检测其他相同进程自动关闭的东西，如果要解决这个东西，先升级强制更新系统，虽然现在似乎问题不大
        # 进程管理器的pid = os.getpid()
        # if Fishsys.进程存活性检测(进程管理器的pid):
        #     print(进程管理器的pid)
        #     print(files.缓存(2,数据={'ProcessManagerPid':进程管理器的pid}))
        #
        #     logs.安全退出("原来的进程存活，非法启动")
        # if not files.缓存(2,数据={'ProcessManagerPid':进程管理器的pid}) in ["ProcessManagerPid"]:
        #     files.缓存(3, 数据={'ProcessManagerPid': 进程管理器的pid})
        #     进程管理器的pid=0*20







        缓存文件名 = 'C:\Fishconsole\programes\Tempfiles\houtai_core.fcc'

        while True:


            res=启动数据源 = files.缓存(2, 文件名=缓存文件名)
            if not res:
                print(logs.日志("文件不存在，自动创建"))
                files.缓存(1, 文件名=缓存文件名,数据={})


            # ipmadom
            if not 启动数据源  == False:
               def __启动():
                   res = multiprocessing.Process(target=ipmadom)
                   res.start()
                   print(logs.日志(f'ipmadom进程已启动a - ({res.pid}) ({res.name})', '红色'))
               try:
                   if 启动数据源['ipmadom']:
                       try:
                           pid=files.缓存(2,文件名=缓存文件名,变量名='ipmadomPid')
                           if not Fishsys.进程存活性检测(pid):
                               __启动()
                           else:
                               print(logs.日志('ipmadom进程正在运行','绿色'))
                       except:
                           print(logs.日志('未检测到ipmadom初始pid，直接启动'))
                           __启动()
               except KeyError:
                   print(logs.日志("缓存为空，可能是被重置，直接启动"))
                   try:
                       pid = files.缓存(2, 文件名=缓存文件名, 变量名='ipmadomPid')
                       if not Fishsys.进程存活性检测(pid):
                           __启动()
                       else:
                           print(logs.日志('ipmadom进程正在运行', '绿色'))
                   except:
                       print('未检测到ipmadom初始pid，直接启动')
                       __启动()
            if not 启动数据源 == False:
               try:#没有文件根它没关系
                   if not 启动数据源['ipmadom']:
                       #检测到fcv_debug要关闭时就关闭
                       pid = files.缓存(2, 文件名=缓存文件名, 变量名='ipmadomPid')
                       if not Fishsys.进程存活性检测(pid):
                           print(logs.日志('ipmadom进程不存在','蓝色'))
                       else:
                           print(logs.日志('ipmadom进程已被杀死', '红色'))
                           os.system(f'taskkill /pid {pid}  -t  -f')
               except KeyError:
                   pass

            # file_protect
            if not 启动数据源  == False:
               def __启动():
                   res = multiprocessing.Process(target=file_protect)
                   res.start()
                   print(logs.日志(f'file_protect进程已启动a - ({res.pid}) ({res.name})', '红色'))
               try:
                   if 启动数据源['file_protect']:
                       try:
                           pid=files.缓存(2,文件名=缓存文件名,变量名='FileprotectPid')
                           if not Fishsys.进程存活性检测(pid):
                               __启动()
                           else:
                               print(logs.日志('file_protect进程正在运行','绿色'))
                       except:
                           print(logs.日志('未检测到file_protect初始pid，直接启动'))
                           __启动()
               except KeyError:
                   print(logs.日志("缓存为空，可能是被重置，直接启动"))
                   try:
                       pid = files.缓存(2, 文件名=缓存文件名, 变量名='FileprotectPid')
                       if not Fishsys.进程存活性检测(pid):
                           __启动()
                       else:
                           print(logs.日志('file_protect进程正在运行', '绿色'))
                   except:
                       print('未检测到file_protect初始pid，直接启动')
                       __启动()
            if not 启动数据源 == False:
               try:#没有文件根它没关系
                   if not 启动数据源['file_protect']:
                       #检测到fcv_debug要关闭时就关闭
                       pid = files.缓存(2, 文件名=缓存文件名, 变量名='FileprotectPid')
                       if not Fishsys.进程存活性检测(pid):
                           print(logs.日志('file_protect进程不存在','蓝色'))
                       else:
                           print(logs.日志('file_protect进程已被杀死', '红色'))
                           os.system(f'taskkill /pid {pid}  -t  -f')
               except KeyError:
                   pass






            print(logs.日志("循环检测完毕"))
            time.sleep(10)






except KeyboardInterrupt:
    from Fishconsole import logs
    print(logs.日志('Fishconsole Main 已安全退出','蓝色'))

    
    '''

    os.makedirs('C:\Fishconsole\programes\FileProtect', exist_ok=True)
    os.makedirs('C:\Fishconsole\programes\Tempfiles', exist_ok=True)
    os.makedirs('C:\Fishconsole\programes\ipmadom', exist_ok=True)
    os.makedirs('C:\Fishconsole\programes\Management', exist_ok=True)

    with open("C:\Fishconsole\programes\Management\Management.py", "w", encoding="utf-8") as f:
        f.write(后台管理器)
        f.close()

    with open("C:\Fishconsole\programes\FileProtect\File_Protect.py", "w", encoding="utf-8") as f:
        f.write(fileprotect)
        f.close()

    with open("C:\Fishconsole\programes\ipmadom\ipmadom.py", "w", encoding="utf-8") as f:
        f.write(代理池)
        f.close()

    用户名 = os.getenv('username')

    with open(f"C:/Users/{用户名}/AppData/Roaming/Microsoft/Windows/Start Menu/Programs/Startup/File_Protect_start.bat", "w",
              encoding="ANSI") as f:
        f.write(start)
        f.close()


except KeyboardInterrupt:
    from Fishconsole import logs
    print(logs.日志('Fishconsole Houtai 已安全退出','蓝色'))